@@ -7,14 +7,12 @@ from circus.client import CircusClient
 from zmq.eventloop import ioloop
 from honcho.procfile import Procfile
 
-import copy
 import json
 import os
 
 
 class ApprcWatcher(CircusPlugin):
     name = "apprc_watcher"
-    envs_to_keep = ("PATH", "http_proxy", "https_proxy", "no_proxy")
 
     def __init__(self, *args, **config):
         super(ApprcWatcher, self).__init__(*args, **config)
@@ -44,8 +42,10 @@ class ApprcWatcher(CircusPlugin):
 
     def add_envs(self, name, envs):
         current = self.call("options", name=name)["options"]["env"]
-        values = copy.deepcopy(os.environ)
-        values.update(envs)
+        values = {}
+        values.update(os.environ, **envs)
+        if "PYTHONPATH" in values and "PYTHONPATH" not in envs:
+            del values["PYTHONPATH"]
         if values != current:
             self.call("set", name=name, options={"env": values})
 
@@ -138,7 +138,7 @@ class ProcfileWatcher(CircusPlugin):
 
     def commands(self, procfile):
         cmds = self.call("status")["statuses"]
-        cmds_names = set(cmds.keys())
+        cmds_names = set([k for k in cmds.keys() if not k.startswith("plugin:")])
         new_cmds = set(procfile.commands.keys())
         to_remove = cmds_names.difference(new_cmds)
         to_add = new_cmds.difference(cmds_names)
